@@ -38,35 +38,50 @@ function smarty_cms_function_toggle_start($params, &$smarty)
 
 	if ($firstToggle) {
 		echo '<link rel="stylesheet" href="../lib/toggle/stylesheet.php?wd='.$width.'"  type="text/css" />';
+                
 		echo '<script type="text/javascript">
-			$(document).ready(function(){
-				
-				$(".toggle_container").hide();
-				$(".active").slideToggle("slow,");
-				$(".active").prev("h2.trigger").addClass("active"); 
-			
-				/*$("h2.trigger").toggle(function(){
-					$(this).addClass("active"); 
-					}, function () {
-					$(this).removeClass("active");
-				});*/
-				
-				$("h2.trigger").click(function(){		
-					$(this).next(".toggle_container").slideToggle("slow,");
-					
-					if ($(this).hasClass("active")){
-						$(this).removeClass("active");
-					}else{
-						//toggle all other open containers first
-						$(".active").next(".toggle_container").slideToggle("slow,");
-						$(".active").removeClass("active");
-						
-						$(this).addClass("active"); 
-					}
-				});
-			
-			});	
-		</script>'
+                    /******** Load jQuery if not present *********/
+                    if (typeof jQuery === "undefined" || jQuery.fn.jquery !== \'1.4.2\') {
+                            var script_tag = document.createElement(\'script\');
+                            script_tag.setAttribute("type","text/javascript");
+                            script_tag.setAttribute("src", "http://ajax.googleapis.com/ajax/libs/jquery/1.4.2/jquery.min.js")
+                            script_tag.onload = main; //Run main() once jQuery has loaded
+                            script_tag.onreadystatechange = function () { //Same thing but for IE
+                                    if (this.readyState == \'complete\' || this.readyState == \'loaded\') main();
+                            } //onreadystatechange.function
+                            document.getElementsByTagName("head")[0].appendChild(script_tag);
+                            } else {
+                                    main();
+                    } //if.jQuery
+
+                    function main() {
+                            $(document).ready(function() {
+                                    $(".toggle_container").hide();
+                                    $(".active").slideToggle("slow,");
+                                    $(".active").prev("h2.trigger").addClass("active"); 
+
+                                    /*$("h2.trigger").toggle(function(){
+                                            $(this).addClass("active"); 
+                                            }, function () {
+                                            $(this).removeClass("active");
+                                    });*/
+
+                                    $("h2.trigger").click(function(){		
+                                            $(this).next(".toggle_container").slideToggle("slow,");
+
+                                            if ($(this).hasClass("active")){
+                                                    $(this).removeClass("active");
+                                            }else{
+                                                    //toggle all other open containers first
+                                                    $(".active").next(".toggle_container").slideToggle("slow,");
+                                                    $(".active").removeClass("active");
+
+                                                    $(this).addClass("active"); 
+                                            }
+                                    });
+                            });
+                    } //function.main
+                    </script>'
 		;
 
 		
@@ -91,14 +106,14 @@ function smarty_cms_help_function_toggle_start() {
 </p>
 		<h3>How do I use it?</h3>
 <p>Just insert the tag into your content or template like: <code>{toggle_start title="text line for the top bar"}</code><br />
-  and close it with <code>{toggle_close}</code><br />
+  and close it with <code>{toggle_end}</code><br />
   <br />
   <strong>For example 1:</strong><br />
   <code>
   {toggle_start title=&quot;Web Design &amp; Development&quot;}<br />
 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;HTML code like pictures, text, place them here ...<br />
 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br />
-  {toggle_close}<br /> 
+  {toggle_end}<br /> 
   <br />
 </code>
   (this 'll output an closed window from 625 pixels width)
@@ -110,7 +125,7 @@ function smarty_cms_help_function_toggle_start() {
   {toggle_start status=&quot;active&quot; width=&quot;750&quot; title=&quot;Web Design &amp; Development&quot;}<br />
 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;HTML code like pictures, text, place them here ...<br />
 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br />
-  {toggle_close}<br /> 
+  {toggle_end}<br /> 
   <br />
 </code>
   (this 'll output an open window from 720 pixels width)
@@ -127,29 +142,18 @@ like this example:<br />
 
   
 <p>&nbsp;</p>
-<h3>Installation:</h3>
-<p><u>1) Load Jquery</u><br />
-  Make sure &quot;jqeury library is loaded&quot; by inserting this line, unless you already have jquery installed in your head section of your template/shabloon.<br />
-<br />
-<code>
-&lt;script type=&quot;text/javascript&quot; src=&quot;lib/toggle/jquery.js&quot;&gt;&lt;/script&gt;<br />
-</code>
-<br />
-Or use jQuery script from Google:<br /><br />
-
-<code>&lt;script type=&quot;text/javascript&quot; src=&quot;https://ajax.googleapis.com/ajax/libs/jquery/1.4.4/jquery.min.js&quot;&gt;&lt;/script&gt;
-</code>
-
-
-</p>
-<p><u>2) Now for easy use you can edit TinyMCE (optional)</u><br />
+<h3>TinyMCE option:</h3>
+<p><u>For easy use, you can edit TinyMCE (optional)</u><br />
   goto admin / Extentsions /TinyMce WYSIWYG<br />
 open tab Advanced, scroll down and edit &quot;Custom dropdown:&quot;</p>
 <p>add this code or change original:<br />
-  ---|---<br />
-  Start expand/collapse-area|{toggle_start title=\'This is my expandable area\'}<br />
-  End expand/collapse-area|{toggle_close}<br />
-  ---|---</p>
+    <textarea class="pagesmalltextarea" style="height: 80px;">
+  ---|---
+  Start expand/collapse-area|{toggle_start title=\'This is my expandable area\'}
+  End expand/collapse-area|{toggle_end}
+  ---|---
+    </textarea>
+</p>
 <p>and save<br />
   now you can use the icon &quot;Specifik Dropdown-menu&quot; in TinyMCE menubar.</p>
 <p>&nbsp; </p>
