@@ -36,7 +36,7 @@ h2.active {
     background-size: 100% auto;
     border-top: 1px solid #D6D6D6;
     clear: both;
-    font-size: 1.2em;
+    /*font-size: 1.2em;*/
     margin: 0 0 5px;
     overflow: hidden;
     padding: 0;
@@ -59,7 +59,7 @@ h2.active {
 .toggle_container img {
     background: none repeat scroll 0 0 #DDDDDD;
     border: 1px solid #CCCCCC;
-    float: left;
+    /*float: left;*/
     margin: 10px 15px 15px 0;
     padding: 5px;
 }
\ No newline at end of file
